------------------------------------------------------------------------------
--                                                                          --
--                An Ada2005 binding to the Qt C++ framework                --
--                                                                          --
------------------------------------------------------------------------------
--                                                                          --
-- Copyright © 2009 Vadim Godunko <vgodunko@gmail.com>                      --
--                                                                          --
-- QtAda is free software;  you can  redistribute it and/or modify it under --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. QtAda is distributed in the hope that it will be useful, but WITH- --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License distributed with QtAda;  see file COPYING.  If not, write --
-- to  the  Free Software Foundation,  51  Franklin  Street,  Fifth  Floor, --
-- Boston, MA 02110-1301, USA.                                              --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------
--  $Revision: 3361 $ $Date: 2009-05-09 14:25:08 +0400 (Sat, 09 May 2009) $
------------------------------------------------------------------------------
with Interfaces.C;

with Qt4.Events.Impl;

package body Qt_Ada.Internals.Events.Registry is

   function type_wrapper (Cpp_Object : not null access QEvent)
     return Interfaces.C.int;
   pragma Import (C, type_wrapper, "__Qt4Ada_QEvent_type_wrapper");

   Registry : array (Qt4.Events.Event_Type) of Event_Constructor
     := (others => null);

   --------------------
   -- Create_Wrapper --
   --------------------

   function Create_Wrapper (Object : not null access QEvent)
     return not null access Qt4.Events.Q_Event'Class
   is
      The_Type    : constant Qt4.Events.Event_Type
        := Qt4.Events.Event_Type (type_wrapper (Object));
      Constructor : Event_Constructor
        := Qt4.Events.Impl.Create_Event'Access;

   begin
      --  If there is the special constructor for this type of event then
      --  use it instead of default one.

      if Registry (The_Type) /= null then
         Constructor := Registry (The_Type);
      end if;

      return
        Qt4.Events.Q_Event'Class
         (Constructor (QEvent_Access (Object)).all)'Access;
   end Create_Wrapper;

   --------------
   -- Register --
   --------------

   procedure Register
    (The_Type    : Qt4.Events.Event_Type;
     Constructor : Event_Constructor)
   is
   begin
      if Registry (The_Type) /= null then
         raise Program_Error
           with "Ada event constructor for"
                   & Qt4.Events.Event_Type'Image (The_Type)
                   & " already registered";
      end if;

      Registry (The_Type) := Constructor;
   end Register;

end Qt_Ada.Internals.Events.Registry;
