------------------------------------------------------------------------------
--                                                                          --
--                An Ada2005 binding to the Qt C++ framework                --
--                                                                          --
------------------------------------------------------------------------------
--                                                                          --
-- Copyright © 2008, 2009 Vadim Godunko <vgodunko@gmail.com>                --
--                                                                          --
-- QtAda is free software;  you can  redistribute it and/or modify it under --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. QtAda is distributed in the hope that it will be useful, but WITH- --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License distributed with QtAda;  see file COPYING.  If not, write --
-- to  the  Free Software Foundation,  51  Franklin  Street,  Fifth  Floor, --
-- Boston, MA 02110-1301, USA.                                              --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------
--  $Revision: 3363 $ $Date: 2009-05-09 15:42:59 +0400 (Sat, 09 May 2009) $
------------------------------------------------------------------------------
with Qt4.Events.Impl;
with Qt_Ada.Internals.Events.Registry;

package body Qt4.Graphics_Scene_Context_Menu_Events.Impl is

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit>
   --!    <ImplementationNotes>
   ---------------------------------------------------------------------------
   function modifiers_wrapper
    (Self : not null access Qt4.Events.Impl.Thin.QEvent)
      return Qt4.Keyboard_Modifiers;
   pragma Import
    (C,
     modifiers_wrapper,
     "__Qt4Ada_QGraphicsSceneContextMenuEvent_modifiers_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> pos_wrapper
   --!    <ImplementationNotes>
   ---------------------------------------------------------------------------
   procedure pos_wrapper
    (Self : not null access Qt4.Events.Impl.Thin.QEvent;
     Pos  : not null access Qt4.Point_Fs.Internals.QPointF);
   pragma Import
    (C, pos_wrapper, "__Qt4Ada_QGraphicsSceneContextMenuEvent_pos_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> reason_wrapper
   --!    <ImplementationNotes>
   ---------------------------------------------------------------------------
   function reason_wrapper (Self : not null access Qt4.Events.Impl.Thin.QEvent)
     return Qt4.Graphics_Scene_Context_Menu_Events.Reason;
   pragma Import
    (C,
     reason_wrapper,
     "__Qt4Ada_QGraphicsSceneContextMenuEvent_reason_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> scenePos_wrapper
   --!    <ImplementationNotes>
   ---------------------------------------------------------------------------
   procedure scenePos_wrapper
    (Self : not null access Qt4.Events.Impl.Thin.QEvent;
     Pos  : not null access Qt4.Point_Fs.Internals.QPointF);
   pragma Import
    (C,
     scenePos_wrapper,
     "__Qt4Ada_QGraphicsSceneContextMenuEvent_scenePos_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> screenPos_wrapper
   --!    <ImplementationNotes>
   ---------------------------------------------------------------------------
   function screenPos_wrapper
    (Self : not null access Qt4.Events.Impl.Thin.QEvent)
       return not null access Qt4.Points.Internals.QPoint;
   pragma Import
    (C,
     screenPos_wrapper,
     "__Qt4Ada_QGraphicsSceneContextMenuEvent_screenPos_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> setReason_wrapper
   --!    <ImplementationNotes>
   ---------------------------------------------------------------------------
   procedure setReason_wrapper
    (Self       : not null access Qt4.Events.Impl.Thin.QEvent;
     The_Reason : in            Qt4.Graphics_Scene_Context_Menu_Events.Reason);
   pragma Import
    (C,
     setReason_wrapper,
     "__Qt4Ada_QGraphicsSceneContextMenuEvent_setReason_wrapper");

   function Create
    (Object : not null Qt_Ada.Internals.Events.QEvent_Access)
       return not null Qt4.Events.Q_Event_Access;

   ------------
   -- Create --
   ------------

   function Create
    (Object : not null Qt_Ada.Internals.Events.QEvent_Access)
       return not null Qt4.Events.Q_Event_Access
   is
   begin
      return Result : constant not null Qt4.Events.Q_Event_Access
        := new Q_Graphics_Scene_Context_Menu_Event_Impl
      do
         Qt_Ada.Internals.Events.Initialize (Result, Object);
      end return;
   end Create;

   ---------------
   -- Modifiers --
   ---------------

   function Modifiers
    (Self : not null access Q_Graphics_Scene_Context_Menu_Event_Impl)
       return Qt4.Keyboard_Modifiers
   is
   begin
      return modifiers_wrapper (Self.QEvent_View);
   end Modifiers;

   ---------
   -- Pos --
   ---------

   function Pos
    (Self : not  null access Q_Graphics_Scene_Context_Menu_Event_Impl)
       return Qt4.Point_Fs.Q_Point_F
   is
   begin
      return Result : Qt4.Point_Fs.Q_Point_F do
         pos_wrapper
          (Self.QEvent_View, Qt4.Point_Fs.Internals.QPointF_View (Result));
      end return;
   end Pos;

   ------------
   -- Reason --
   ------------

   function Reason
    (Self : not null access Q_Graphics_Scene_Context_Menu_Event_Impl)
       return Qt4.Graphics_Scene_Context_Menu_Events.Reason
   is
   begin
      return reason_wrapper (Self.QEvent_View);
   end Reason;

   ---------------
   -- Scene_Pos --
   ---------------

   function Scene_Pos
    (Self : not  null access Q_Graphics_Scene_Context_Menu_Event_Impl)
       return Qt4.Point_Fs.Q_Point_F
   is
   begin
      return Result : Qt4.Point_Fs.Q_Point_F do
         scenePos_wrapper
          (Self.QEvent_View, Qt4.Point_Fs.Internals.QPointF_View (Result));
      end return;
   end Scene_Pos;

   ----------------
   -- Screen_Pos --
   ----------------

   function Screen_Pos
    (Self : not  null access Q_Graphics_Scene_Context_Menu_Event_Impl)
       return Qt4.Points.Q_Point
   is
   begin
      return
        Qt4.Points.Internals.Create_Wrapper
         (Qt4.Points.Internals.QPoint_Access
           (screenPos_wrapper (Self.QEvent_View)));
   end Screen_Pos;

   ----------------
   -- Set_Reason --
   ----------------

   procedure Set_Reason
    (Self       : not null access Q_Graphics_Scene_Context_Menu_Event_Impl;
     The_Reason : in            Qt4.Graphics_Scene_Context_Menu_Events.Reason)
   is
   begin
      setReason_wrapper (Self.QEvent_View, The_Reason);
   end Set_Reason;

begin
   Qt_Ada.Internals.Events.Registry.Register
    (Qt4.Events.Graphics_Scene_Context_Menu, Create'Access);
end Qt4.Graphics_Scene_Context_Menu_Events.Impl;
