------------------------------------------------------------------------------
--                                                                          --
--                An Ada2005 binding to the Qt C++ framework                --
--                                                                          --
------------------------------------------------------------------------------
--                                                                          --
-- Copyright © 2008, 2009 Vadim Godunko <vgodunko@gmail.com>                --
--                                                                          --
-- QtAda is free software;  you can  redistribute it and/or modify it under --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. QtAda is distributed in the hope that it will be useful, but WITH- --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License distributed with QtAda;  see file COPYING.  If not, write --
-- to  the  Free Software Foundation,  51  Franklin  Street,  Fifth  Floor, --
-- Boston, MA 02110-1301, USA.                                              --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------
--  $Revision: 3363 $ $Date: 2009-05-09 15:42:59 +0400 (Sat, 09 May 2009) $
------------------------------------------------------------------------------
with Qt_Ada.Internals.Events.Registry;

package body Qt4.Help_Events.Impl is

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> globalPos_wrapper
   --!    <Purpose> Обёртка для функции QObject::globalPos.
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function globalPos_wrapper
    (Cpp_Object : not null access Qt4.Events.Impl.Thin.QEvent)
       return not null access Qt4.Points.Internals.QPoint;
   pragma Import
    (C, globalPos_wrapper, "__Qt4Ada_QHelpEvent_globalPos_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> pos_wrapper
   --!    <Purpose> Обёртка для функции QObject::pos.
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function pos_wrapper
    (Cpp_Object : not null access Qt4.Events.Impl.Thin.QEvent)
       return not null access Qt4.Points.Internals.QPoint;
   pragma Import (C, pos_wrapper, "__Qt4Ada_QHelpEvent_pos_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> globalX_wrapper
   --!    <Purpose> Обёртка для функции QObject::globalX.
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function globalX_wrapper
    (Cpp_Object : not null access Qt4.Events.Impl.Thin.QEvent)
       return Interfaces.C.int;
   pragma Import (C, globalX_wrapper, "__Qt4Ada_QHelpEvent_globalX_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> globalY_wrapper
   --!    <Purpose> Обёртка для функции QObject::globalY.
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function globalY_wrapper
    (Cpp_Object : not null access Qt4.Events.Impl.Thin.QEvent)
       return Interfaces.C.int;
   pragma Import (C, globalY_wrapper, "__Qt4Ada_QHelpEvent_globalY_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> x_wrapper
   --!    <Purpose> Обёртка для функции QObject::x.
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function x_wrapper
    (Cpp_Object : not null access Qt4.Events.Impl.Thin.QEvent)
       return Interfaces.C.int;
   pragma Import (C, x_wrapper, "__Qt4Ada_QHelpEvent_x_wrapper");

   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> y_wrapper
   --!    <Purpose> Обёртка для функции QObject::y.
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function y_wrapper
    (Cpp_Object : not null access Qt4.Events.Impl.Thin.QEvent)
       return Interfaces.C.int;
   pragma Import (C, y_wrapper, "__Qt4Ada_QHelpEvent_y_wrapper");

   function Create
    (Object : not null Qt_Ada.Internals.Events.QEvent_Access)
       return not null Qt4.Events.Q_Event_Access;

   ------------
   -- Create --
   ------------

   function Create
    (Object : not null Qt_Ada.Internals.Events.QEvent_Access)
       return not null Qt4.Events.Q_Event_Access
   is
   begin
      return Result : constant not null Qt4.Events.Q_Event_Access
        := new Q_Help_Event_Impl
      do
         Qt_Ada.Internals.Events.Initialize (Result, Object);
      end return;
   end Create;

   ----------------
   -- Global_Pos --
   ----------------

   function Global_Pos (Self : not null access Q_Help_Event_Impl)
     return Qt4.Points.Q_Point
   is
   begin
      return
        Qt4.Points.Internals.Create_Wrapper
         (Qt4.Points.Internals.QPoint_Access
           (globalPos_wrapper (Self.QEvent_View)));
   end Global_Pos;

   --------------
   -- Global_X --
   --------------

   function Global_X (Self : not null access Q_Help_Event_Impl)
     return Qt4.Q_Integer
   is
   begin
      return Qt4.Q_Integer (globalX_wrapper (Self.QEvent_View));
   end Global_X;

   --------------
   -- Global_Y --
   --------------

   function Global_Y (Self : not null access Q_Help_Event_Impl)
     return Qt4.Q_Integer
   is
   begin
      return Qt4.Q_Integer (globalY_wrapper (Self.QEvent_View));
   end Global_Y;

   ---------
   -- Pos --
   ---------

   function Pos (Self : not null access Q_Help_Event_Impl)
     return Qt4.Points.Q_Point
   is
   begin
      return
        Qt4.Points.Internals.Create_Wrapper
         (Qt4.Points.Internals.QPoint_Access
           (pos_wrapper (Self.QEvent_View)));
   end Pos;

   -------
   -- X --
   -------

   function X (Self : not null access Q_Help_Event_Impl)
     return Qt4.Q_Integer
   is
   begin
      return Qt4.Q_Integer (x_wrapper (Self.QEvent_View));
   end X;

   -------
   -- Y --
   -------

   function Y (Self : not null access Q_Help_Event_Impl)
     return Qt4.Q_Integer
   is
   begin
      return Qt4.Q_Integer (y_wrapper (Self.QEvent_View));
   end Y;

begin
   Qt_Ada.Internals.Events.Registry.Register
    (Qt4.Events.Tool_Tip, Create'Access);
   Qt_Ada.Internals.Events.Registry.Register
    (Qt4.Events.Whats_This, Create'Access);
   Qt_Ada.Internals.Events.Registry.Register
    (Qt4.Events.Graphics_Scene_Help, Create'Access);
end Qt4.Help_Events.Impl;
